@@ -14,7 +14,8 @@ using namespace Kontact;
 
 #include <KAboutData>
 #include <KLocalizedString>
-#include <KServiceTypeTrader>
+#include <KPluginFactory>
+#include <KPluginLoader>
 #include <QComboBox>
 
 #include <QCheckBox>
@@ -22,25 +23,19 @@ using namespace Kontact;
 #include <QHBoxLayout>
 #include <QStandardItemModel>
 
-extern "C" {
-Q_DECL_EXPORT KCModule *create_kontactconfig(QWidget *parent, const char *)
-{
-    return new KcmKontact(parent);
-}
-}
-
-KcmKontact::KcmKontact(QWidget *parent)
-    : KCModule(parent)
+K_PLUGIN_FACTORY_WITH_JSON(KCMKontactSummaryFactory, "kontactconfig.json", registerPlugin<KcmKontact>();)
+KcmKontact::KcmKontact(QWidget *parent, const QVariantList &args)
+    : KCModule(parent, args)
+    , mPluginCombo(new QComboBox(parent))
 {
     auto topLayout = new QVBoxLayout(this);
     QBoxLayout *pluginStartupLayout = new QHBoxLayout();
     topLayout->addLayout(pluginStartupLayout);
 
-    QCheckBox *forceStartupPluginCheckBox = new QCheckBox(Prefs::self()->forceStartupPluginItem()->label(), this);
+    auto forceStartupPluginCheckBox = new QCheckBox(Prefs::self()->forceStartupPluginItem()->label(), this);
     forceStartupPluginCheckBox->setObjectName(QStringLiteral("kcfg_ForceStartupPlugin"));
     pluginStartupLayout->addWidget(forceStartupPluginCheckBox);
 
-    mPluginCombo = new QComboBox(parent);
     mPluginCombo->setToolTip(i18nc("@info:tooltip", "Select the initial plugin to use on each start"));
     mPluginCombo->setWhatsThis(i18nc("@info:whatsthis",
                                      "Select the plugin from this drop down list to be used as the "
@@ -53,10 +48,9 @@ KcmKontact::KcmKontact(QWidget *parent)
     pluginStartupLayout->addStretch();
     mPluginCombo->setEnabled(false);
 
-
     connect(forceStartupPluginCheckBox, &QAbstractButton::toggled, mPluginCombo, &QWidget::setEnabled);
 
-    QCheckBox *showSideBarCheckbox = new QCheckBox(Prefs::self()->sideBarOpenItem()->label(), this);
+    auto showSideBarCheckbox = new QCheckBox(Prefs::self()->sideBarOpenItem()->label(), this);
     showSideBarCheckbox->setObjectName(QStringLiteral("kcfg_SideBarOpen"));
     topLayout->addWidget(showSideBarCheckbox);
 
@@ -69,30 +63,35 @@ void KcmKontact::load()
 {
     const KConfigGroup grp(Prefs::self()->config(), "Plugins");
 
-    const KService::List offers =
-        KServiceTypeTrader::self()->query(QStringLiteral("Kontact/Plugin"), QStringLiteral("[X-KDE-KontactPluginVersion] == %1").arg(KONTACT_PLUGIN_VERSION));
+    const QVector<KPluginMetaData> pluginMetaDatas = KPluginLoader::findPlugins(QStringLiteral("kontact5"), [](const KPluginMetaData &data) {
+        return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
+    });
 
     int activeComponent = 0;
     mPluginCombo->clear();
     mPluginList.clear();
-    for (const KService::Ptr &service : offers) {
+    for (const KPluginMetaData &plugin : pluginMetaDatas) {
         // skip summary only plugins
-        QVariant var = service->property(QStringLiteral("X-KDE-KontactPluginHasPart"));
-        if (var.isValid() && var.toBool() == false) {
-            continue;
+        if (plugin.rawData().contains(QLatin1String("X-KDE-KontactPluginHasPart"))) {
+            bool var = plugin.rawData().value(QStringLiteral("X-KDE-KontactPluginHasPart")).toBool();
+
+            if (!var) {
+                continue;
+            }
         }
-        mPluginCombo->addItem(service->name());
-        mPluginList.append(service);
+
+        mPluginCombo->addItem(plugin.name());
+        mPluginList.append(plugin);
 
         // skip disabled plugins
-        const QString pluginName = service->property(QStringLiteral("X-KDE-PluginInfo-Name")).toString();
+        const QString pluginName = plugin.pluginId();
         if (!grp.readEntry(pluginName + QStringLiteral("Enabled"), false)) {
             const QStandardItemModel *qsm = qobject_cast<QStandardItemModel *>(mPluginCombo->model());
             if (qsm) {
                 qsm->item(mPluginCombo->count() - 1, 0)->setEnabled(false);
             }
         }
-        if (service->property(QStringLiteral("X-KDE-PluginInfo-Name")).toString() == Prefs::self()->activePlugin()) {
+        if (pluginName == Prefs::self()->activePlugin()) {
             activeComponent = mPluginList.count() - 1;
         }
     }
@@ -103,23 +102,23 @@ void KcmKontact::load()
 
 void KcmKontact::save()
 {
-    const KService::Ptr ptr = mPluginList.at(mPluginCombo->currentIndex());
-    const QString activePluginName = ptr->property(QStringLiteral("X-KDE-PluginInfo-Name")).toString();
-    Prefs::self()->setActivePlugin(activePluginName);
+    const KPluginMetaData plugin = mPluginList.at(mPluginCombo->currentIndex());
+    Prefs::self()->setActivePlugin(plugin.pluginId());
     KCModule::save();
 }
 
 const KAboutData *KcmKontact::aboutData() const
 {
-    KAboutData *about = new KAboutData(QStringLiteral("kontactconfig"),
-                                       i18nc("@title", "KDE Kontact"),
-                                       QString(),
-                                       QString(),
-                                       KAboutLicense::GPL,
-                                       i18nc("@info:credit", "(c), 2003 Cornelius Schumacher"));
+    auto about = new KAboutData(QStringLiteral("kontactconfig"),
+                                i18nc("@title", "KDE Kontact"),
+                                QString(),
+                                QString(),
+                                KAboutLicense::GPL,
+                                i18nc("@info:credit", "(c), 2003 Cornelius Schumacher"));
 
     about->addAuthor(i18nc("@info:credit", "Cornelius Schumacher"), i18nc("@info:credit", "Developer"), QStringLiteral("schumacher@kde.org"));
     about->addAuthor(i18nc("@info:credit", "Tobias Koenig"), i18nc("@info:credit", "Developer"), QStringLiteral("tokoe@kde.org"));
 
     return about;
 }
+#include "kcmkontact.moc"
